# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v3.15.3~bdb9768',
    built_at='2022-09-17 16:53:51Z',
    sha='bdb9768c9e8212f29991a4967bf2cc5800630c1f',
    branch='HEAD',
    tag='v3.15.3',
)
